pub struct ExecutionMassStatus {
pub client_id: ClientId,
pub account_id: AccountId,
pub venue: Venue,
pub report_id: UUID4,
pub ts_init: UnixNanos,
/* private fields */
}Expand description
Represents an execution mass status report for an execution client - including status of all orders, trades for those orders and open positions.
Fields
client_id: ClientIdThe client ID for the report.
account_id: AccountIdThe account ID for the report.
venue: VenueThe venue for the report.
report_id: UUID4The report ID.
ts_init: UnixNanosUNIX timestamp (nanoseconds) when the object was initialized.
Implementations
Sourceimpl ExecutionMassStatus
impl ExecutionMassStatus
Sourcepub fn new(
client_id: ClientId,
account_id: AccountId,
venue: Venue,
ts_init: UnixNanos,
report_id: Option<UUID4>,
) -> Self
pub fn new( client_id: ClientId, account_id: AccountId, venue: Venue, ts_init: UnixNanos, report_id: Option<UUID4>, ) -> Self
Creates a new execution mass status report.
Sourcepub fn order_reports(&self) -> IndexMap<VenueOrderId, OrderStatusReport>
pub fn order_reports(&self) -> IndexMap<VenueOrderId, OrderStatusReport>
Get a copy of the order reports map.
Sourcepub fn fill_reports(&self) -> IndexMap<VenueOrderId, Vec<FillReport>>
pub fn fill_reports(&self) -> IndexMap<VenueOrderId, Vec<FillReport>>
Get a copy of the fill reports map.
Sourcepub fn position_reports(
&self,
) -> IndexMap<InstrumentId, Vec<PositionStatusReport>>
pub fn position_reports( &self, ) -> IndexMap<InstrumentId, Vec<PositionStatusReport>>
Get a copy of the position reports map.
Sourcepub fn add_order_reports(&mut self, reports: Vec<OrderStatusReport>)
pub fn add_order_reports(&mut self, reports: Vec<OrderStatusReport>)
Add order reports to the mass status.
Sourcepub fn add_fill_reports(&mut self, reports: Vec<FillReport>)
pub fn add_fill_reports(&mut self, reports: Vec<FillReport>)
Add fill reports to the mass status.
Sourcepub fn add_position_reports(&mut self, reports: Vec<PositionStatusReport>)
pub fn add_position_reports(&mut self, reports: Vec<PositionStatusReport>)
Add position reports to the mass status.
Sourceimpl ExecutionMassStatus
impl ExecutionMassStatus
Sourcepub fn py_from_dict(py: Python<'_>, values: Py<PyDict>) -> PyResult<Self>
pub fn py_from_dict(py: Python<'_>, values: Py<PyDict>) -> PyResult<Self>
Creates an ExecutionMassStatus from a Python dictionary.
Errors
Returns a Python exception if conversion from dict fails.